==> libtangle_0.0.20100830.tar.gz: libtangle-0.0.20100830/tangle/tangle.h <==
/*
 * tangle.h
 *
 * This file is part of Tangle Toolkit - A graphical widget library based on Clutter Toolkit
 *
 * (c) 2010 Henrik Hedberg <henrik.hedberg@innologies.fi>
 *
 */


#ifndef __TANGLE_H__
#define __TANGLE_H__

#include "tangle-action.h"
#include "tangle-actor.h"
#include "tangle-apply-template-action.h"
#include "tangle-binding.h"
#include "tangle-box-layout.h"
#include "tangle-button.h"
#include "tangle-button-group.h"
#include "tangle-call-function-action.h"
#include "tangle-clamp.h"
#include "tangle-compound-style.h"
#include "tangle-curved-transition.h"
#include "tangle-draggable-actor.h"
#include "tangle-droppable-actor.h"
#include "tangle-easing-transition.h"
#include "tangle-event.h"
#include "tangle-floating-actor.h"
#include "tangle-grid.h"
#include "tangle-layout.h"
#include "tangle-layout-meta.h"
#include "tangle-linear-gradient.h"
#include "tangle-multiplexed-transition.h"
#include "tangle-misc.h"
#include "tangle-object.h"
#include "tangle-properties.h"
#include "tangle-scrollbar.h"
#include "tangle-scroller.h"
#include "tangle-scrolling-actor.h"
#include "tangle-set-property-action.h"
#include "tangle-show-actor-action.h"
#include "tangle-stack-layout.h"
#include "tangle-stylable.h"
#include "tangle-style.h"
#include "tangle-stylesheet.h"
#include "tangle-timeline.h"
#include "tangle-template.h"
#include "tangle-transition.h"
#include "tangle-vault.h"
#include "tangle-view.h"
#include "tangle-warehouse.h"
#include "tangle-widget.h"
#include "tangle-wrapper-actor.h"

#endif

==> libtangle_0.0.20100917.tar.gz: libtangle-0.0.20100917/tangle/tangle.h <==
/*
 * tangle.h
 *
 * This file is part of Tangle Toolkit - A graphical widget library based on Clutter Toolkit
 *
 * (c) 2010 Henrik Hedberg <henrik.hedberg@innologies.fi>
 *
 */


#ifndef __TANGLE_H__
#define __TANGLE_H__

#include "tangle-action.h"
#include "tangle-actor.h"
#include "tangle-apply-template-action.h"
#include "tangle-binding.h"
#include "tangle-box-layout.h"
#include "tangle-button.h"
#include "tangle-button-group.h"
#include "tangle-call-function-action.h"
#include "tangle-clamp.h"
#include "tangle-compound-style.h"
#include "tangle-curved-transition.h"
#include "tangle-drag-action.h"
#include "tangle-draggable-actor.h"
#include "tangle-drop-action.h"
#include "tangle-droppable-actor.h"
#include "tangle-easing-transition.h"
#include "tangle-fixed-layout.h"
#include "tangle-floating-actor.h"
#include "tangle-grid.h"
#include "tangle-layout.h"
#include "tangle-layout-meta.h"
#include "tangle-linear-gradient.h"
#include "tangle-multiplexed-transition.h"
#include "tangle-misc.h"
#include "tangle-object.h"
#include "tangle-opacity-effect.h"
#include "tangle-properties.h"
#include "tangle-scroll-action.h"
#include "tangle-scroll-trick.h"
#include "tangle-scrollbar.h"
#include "tangle-scroller.h"
#include "tangle-scrolling-actor.h"
#include "tangle-set-property-action.h"
#include "tangle-show-actor-action.h"
#include "tangle-stack-layout.h"
#include "tangle-stretch-action.h"
#include "tangle-stylable.h"
#include "tangle-style.h"
#include "tangle-stylesheet.h"
#include "tangle-timeline.h"
#include "tangle-template.h"
#include "tangle-transition.h"
#include "tangle-trick.h"
#include "tangle-vault.h"
#include "tangle-view.h"
#include "tangle-warehouse.h"
#include "tangle-widget.h"
#include "tangle-wrapper-actor.h"

#endif
